@@ -3,11 +3,13 @@ from typing import Optional, List, Sequence
 
 from git import Repo
 
+from flexlate import exc
 from flexlate.adder import Adder
 from flexlate.add_mode import AddMode
 from flexlate.branch_update import get_flexlate_branch_name
 from flexlate.config_manager import ConfigManager
 from flexlate.constants import DEFAULT_MERGED_BRANCH_NAME, DEFAULT_TEMPLATE_BRANCH_NAME
+from flexlate.error_handler import simple_output_for_exceptions
 from flexlate.finder.multi import MultiFinder
 from flexlate.merger import Merger
 from flexlate.pusher import Pusher
@@ -52,6 +54,7 @@ class Flexlate:
         self.updater = updater
         self.undoer = undoer
 
+    @simple_output_for_exceptions(exc.GitRepoDirtyException)
     def init_project(
         self,
         path: Path = Path("."),
@@ -104,6 +107,9 @@ class Flexlate:
             template_branch_name=template_branch_name,
         )
 
+    @simple_output_for_exceptions(
+        exc.GitRepoDirtyException, exc.TemplateSourceWithNameAlreadyExistsException
+    )
     def add_template_source(
         self,
         path: str,
@@ -140,6 +146,7 @@ class Flexlate:
             config_manager=self.config_manager,
         )
 
+    @simple_output_for_exceptions(exc.GitRepoDirtyException)
     def remove_template_source(
         self,
         template_name: str,
@@ -170,6 +177,7 @@ class Flexlate:
             config_manager=self.config_manager,
         )
 
+    @simple_output_for_exceptions(exc.GitRepoDirtyException)
     def apply_template_and_add(
         self,
         name: str,
@@ -209,6 +217,7 @@ class Flexlate:
             updater=self.updater,
         )
 
+    @simple_output_for_exceptions(exc.GitRepoDirtyException)
     def remove_applied_template_and_output(
         self,
         template_name: str,
@@ -240,6 +249,7 @@ class Flexlate:
             renderer=self.renderer,
         )
 
+    @simple_output_for_exceptions(exc.GitRepoDirtyException)
     def update(
         self,
         names: Optional[List[str]] = None,
@@ -265,10 +275,9 @@ class Flexlate:
             ]
         else:
             # User wants to update all templates
-            renderables = self.config_manager.get_all_renderables(
+            templates = self.config_manager.get_all_templates(
                 project_root=project_config.path
             )
-            templates = [renderable.template for renderable in renderables]
         self.updater.update_passed_templates_to_target_versions(
             templates,
             project_root=project_config.path,
@@ -301,6 +310,7 @@ class Flexlate:
             config_manager=self.config_manager,
         )
 
+    @simple_output_for_exceptions(exc.GitRepoDirtyException)
     def undo(self, num_operations: int = 1, project_path: Path = Path(".")):
         project_config = self.config_manager.load_project_config(project_path)
         repo = Repo(project_config.path)
@@ -317,6 +327,9 @@ class Flexlate:
             base_template_branch_name=project_config.template_branch_name,
         )
 
+    @simple_output_for_exceptions(
+        exc.GitRepoDirtyException, exc.UnnecessarySyncException
+    )
     def sync(
         self,
         prompt: bool = False,
